AlbumSortType enum
Defines the sort type used for queryAlbums.
Values
- ALBUM → const AlbumSortType
-
ALBUM will return album list based in
albumnames. - ARTIST → const AlbumSortType
-
ARTIST will return album list based in
artistnames. - NUM_OF_SONGS → const AlbumSortType
-
NUM_OF_SONGS will return album list based in
number_of_songs.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AlbumSortType> - A constant List of the values in this enum, in order of their declaration.