SongSortType enum
Defines the sort type used for querySongs and queryAudios.
Values
- TITLE → const SongSortType
-
TITLE will return song list using
titleas sort param. - ARTIST → const SongSortType
- ALBUM → const SongSortType
- DURATION → const SongSortType
-
DURATION will return song list based in song
duration. - DATE_ADDED → const SongSortType
-
DATE_ADDED will return song list based in
data_added. - SIZE → const SongSortType
-
SIZE will return song list based in song
size. - DISPLAY_NAME → const SongSortType
-
DISPLAY_NAME will return song list based in song
display_name.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SongSortType> - A constant List of the values in this enum, in order of their declaration.