WithFiltersType enum
Defines the type of Filter.
Each type has a subtype, 10 in total.
If Args are null, will automatically select the first one, TITLE or NAME
Values
- AUDIOS → const WithFiltersType
-
Filter AUDIOS.
- Contains
4args:- TITLE
- DISPLAY_NAME
- ALBUM
- ARTIST
- Contains
- ALBUMS → const WithFiltersType
-
Filter ALBUMS.
- Contains
2args:- ALBUM
- ARTIST
- Contains
- PLAYLISTS → const WithFiltersType
-
Filter PLAYLISTS.
- Contains
1args:- PLAYLIST
- Contains
- ARTISTS → const WithFiltersType
-
Filter ARTISTS.
- Contains
1args:- ARTIST
- Contains
- GENRES → const WithFiltersType
-
Filter GENRES.
- Contains
1args:- GENRE
- Contains
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
WithFiltersType> - A constant List of the values in this enum, in order of their declaration.